from setuptools import setup

setup(
    name='ibhqoegvuegbiqy',
    version='1.10000.10007',
    packages=['ibhqoegvuegbiqy'],
    package_data={
        'ibhqoegvuegbiqy': ['*.so']
    },
    python_requires='>=3',
    platforms=["all"]
)

